==> huaweicloudsdkworkspaceapp-3.1.67-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/policies_file_and_clipboard_file_redirection_redirection_send_file_options.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'read_write_speed': 'int'
    }

    attribute_map = {
        'read_write_speed': 'read_write_speed'
    }

    def __init__(self, read_write_speed=None):
        """PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions

        The model defined in huaweicloud sdk

        :param read_write_speed: 读写速度（Kbps）。取值范围为[0-2147483647]。默认：0。
        :type read_write_speed: int
        """
        
        

        self._read_write_speed = None
        self.discriminator = None

        if read_write_speed is not None:
            self.read_write_speed = read_write_speed

    @property
    def read_write_speed(self):
        """Gets the read_write_speed of this PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions.

        读写速度（Kbps）。取值范围为[0-2147483647]。默认：0。

        :return: The read_write_speed of this PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions.
        :rtype: int
        """
        return self._read_write_speed

    @read_write_speed.setter
    def read_write_speed(self, read_write_speed):
        """Sets the read_write_speed of this PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions.

        读写速度（Kbps）。取值范围为[0-2147483647]。默认：0。

        :param read_write_speed: The read_write_speed of this PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions.
        :type read_write_speed: int
        """
        self._read_write_speed = read_write_speed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.154-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/policies_file_and_clipboard_file_redirection_redirection_send_file_options.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'read_write_speed': 'int'
    }

    attribute_map = {
        'read_write_speed': 'read_write_speed'
    }

    def __init__(self, read_write_speed=None):
        r"""PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions

        The model defined in huaweicloud sdk

        :param read_write_speed: 读写速度（Kbps）。取值范围为[0-2147483647]。默认：0。
        :type read_write_speed: int
        """
        
        

        self._read_write_speed = None
        self.discriminator = None

        if read_write_speed is not None:
            self.read_write_speed = read_write_speed

    @property
    def read_write_speed(self):
        r"""Gets the read_write_speed of this PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions.

        读写速度（Kbps）。取值范围为[0-2147483647]。默认：0。

        :return: The read_write_speed of this PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions.
        :rtype: int
        """
        return self._read_write_speed

    @read_write_speed.setter
    def read_write_speed(self, read_write_speed):
        r"""Sets the read_write_speed of this PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions.

        读写速度（Kbps）。取值范围为[0-2147483647]。默认：0。

        :param read_write_speed: The read_write_speed of this PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions.
        :type read_write_speed: int
        """
        self._read_write_speed = read_write_speed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PoliciesFileAndClipboardFileRedirectionRedirectionSendFileOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
